@@ -117,8 +117,20 @@ int gsm_bts_model_register(struct gsm_bts_model *model)
 	return 0;
 }
 
-static const uint8_t bts_cell_timer_default[] =
-				{ 3, 3, 3, 3, 3, 10, 3, 10, 3, 10, 3 };
+static const uint8_t bts_cell_timer_default[11] = {
+	3,	/* blocking timer (T1) */
+	3,	/* blocking retries */
+	3,	/* unblocking retries */
+	3,	/* reset timer (T2) */
+	3,	/* reset retries */
+	10,	/* suspend timer (T3) in 100ms */
+	3,	/* suspend retries */
+	10,	/* resume timer (T4) in 100ms */
+	3,	/* resume retries */
+	10,	/* capability update timer (T5) */
+	 3,	/* capability update retries */
+};
+
 static const struct gprs_rlc_cfg rlc_cfg_default = {
 	.parameter = {
 		[RLC_T3142] = 20,
@@ -458,6 +470,7 @@ struct gsm_bts *gsm_bts_alloc(struct gsm_network *net, struct gsm_bts_sm *bts_sm
 	bts->interf_meas_params_cfg = interf_meas_params_def;
 
 	bts->rach_max_delay = 63;
+	bts->rach_expiry_timeout = 32;
 
 	/* SRVCC is enabled by default */
 	bts->srvcc_fast_return_allowed = true;
@@ -888,14 +901,14 @@ int bts_depend_is_depedency(struct gsm_bts *base, struct gsm_bts *other)
 	return (base->depends_on[idx] & (1U << bit)) > 0;
 }
 
-static int bts_is_online(struct gsm_bts *bts)
+static bool bts_is_online(const struct gsm_bts *bts)
 {
 	/* TODO: support E1 BTS too */
-	if (!is_ipaccess_bts(bts))
-		return 1;
+	if (!is_ipa_abisip_bts(bts))
+		return true;
 
 	if (!bts->oml_link)
-		return 0;
+		return false;
 
 	return bts->mo.nm_state.operational == NM_OPSTATE_ENABLED;
 }
@@ -978,21 +991,32 @@ int gsm_bts_set_system_infos(struct gsm_bts *bts)
 	return 0;
 }
 
+/* Send the given C0 power reduction value to the BTS */
+int gsm_bts_send_c0_power_red(const struct gsm_bts *bts, const uint8_t red)
+{
+	if (!bts_is_online(bts))
+		return -ENOTCONN;
+	if (!osmo_bts_has_feature(&bts->features, BTS_FEAT_BCCH_POWER_RED))
+		return -ENOTSUP;
+	if (bts->model->power_ctrl_send_c0_power_red == NULL)
+		return -ENOTSUP;
+	return bts->model->power_ctrl_send_c0_power_red(bts, red);
+}
+
+/* Send the given C0 power reduction value to the BTS and update the internal state */
 int gsm_bts_set_c0_power_red(struct gsm_bts *bts, const uint8_t red)
 {
 	struct gsm_bts_trx *c0 = bts->c0;
 	unsigned int tn;
 	int rc;
 
-	if (!osmo_bts_has_feature(&bts->features, BTS_FEAT_BCCH_POWER_RED))
-		return -ENOTSUP;
-	if (bts->model->power_ctrl_set_c0_power_red == NULL)
-		return -ENOTSUP;
-
-	rc = bts->model->power_ctrl_set_c0_power_red(bts, red);
+	rc = gsm_bts_send_c0_power_red(bts, red);
 	if (rc != 0)
 		return rc;
 
+	LOG_BTS(bts, DRSL, LOGL_NOTICE, "%sabling BCCH carrier power reduction "
+		"operation mode (maximum %u dB)\n", red ? "En" : "Dis", red);
+
 	/* Timeslot 0 is always transmitting BCCH/CCCH */
 	c0->ts[0].c0_max_power_red_db = 0;
 
@@ -1003,7 +1027,7 @@ int gsm_bts_set_c0_power_red(struct gsm_bts *bts, const uint8_t red)
 		switch (ts->pchan_is) {
 		/* Not allowed on CCCH/BCCH */
 		case GSM_PCHAN_CCCH:
-			/* Preceeding timeslot shall not exceed 2 dB */
+			/* Preceding timeslot shall not exceed 2 dB */
 			if (prev->c0_max_power_red_db > 0)
 				prev->c0_max_power_red_db = 2;
 			/* fall-through */
@@ -1632,12 +1656,12 @@ const struct osmo_stat_item_desc bts_stat_desc[] = {
 		  "Number of SDCCH8 channels total",
 		  "", 60, 0 },
 	[BTS_STAT_CHAN_TCH_F_PDCH_USED] = \
-		{ "chan_tch_f_pdch:used",
-		  "Number of TCH/F_PDCH channels used",
+		{ "chan_dynamic_ipaccess:used",
+		  "Number of DYNAMIC/IPACCESS channels used",
 		  "", 60, 0 },
 	[BTS_STAT_CHAN_TCH_F_PDCH_TOTAL] = \
-		{ "chan_tch_f_pdch:total",
-		  "Number of TCH/F_PDCH channels total",
+		{ "chan_dynamic_ipaccess:total",
+		  "Number of DYNAMIC/IPACCESS channels total",
 		  "", 60, 0 },
 	[BTS_STAT_CHAN_CCCH_SDCCH4_CBCH_USED] = \
 		{ "chan_ccch_sdcch4_cbch:used",
@@ -1656,12 +1680,12 @@ const struct osmo_stat_item_desc bts_stat_desc[] = {
 		  "Number of SDCCH8+CBCH channels total",
 		  "", 60, 0 },
 	[BTS_STAT_CHAN_OSMO_DYN_USED] = \
-		{ "chan_osmo_dyn:used",
-		  "Number of TCH/F_TCH/H_SDCCH8_PDCH channels used",
+		{ "chan_dynamic_osmocom:used",
+		  "Number of DYNAMIC/OSMOCOM channels used",
 		  "", 60, 0 },
 	[BTS_STAT_CHAN_OSMO_DYN_TOTAL] = \
-		{ "chan_osmo_dyn:total",
-		  "Number of TCH/F_TCH/H_SDCCH8_PDCH channels total",
+		{ "chan_dynamic_osmocom:total",
+		  "Number of DYNAMIC/OSMOCOM channels total",
 		  "", 60, 0 },
 	[BTS_STAT_T3122] = \
 		{ "T3122",
